/*
 * @Author       : stark1898y 1658608470@qq.com
 * @Date         : 2024-12-15 15:01:15
 * @LastEditors  : stark1898y 1658608470@qq.com
 * @LastEditTime : 2025-05-22 17:01:27
 * @FilePath     : \iot_-scv_-ch584-m(1)\bsp\src\bsp_valve.c
 * @Description  :
 *
 * Copyright (c) 2024 by yzy, All Rights Reserved.
 */
#include "bsp_valve.h"
#include "bsp_motor.h"
// 0xAA CMD/DATA/ DATA_LEN (DATA) checksum 0x55

#include "bsp_uart.h"
#include "log.h"
#include "peripheral.h"
#include "SLEEP.h"
#include "bsp_adc.h"
#include "bsp_led.h"
#include "bsp_bmp390.h"
#include "bsp_tim.h"
#include "bsp_ml307r.h"

#undef LOG_ENABLE
#define LOG_ENABLE 1

// #undef LOG_TAG
// #define LOG_TAG "BSP_VALVE"

TsValveData gValveData = {0};
TsRawFrameData RelyData;
TsTimerCloseState gTimerCloseState = {0};
TeFrameCmd gValveCloseReason = kCmdCloseVavle; // 默认为普通关阀命令
TeFrameCmd gValveOpenReason = kCmdOpenVavle;  // 默认为普通开阀命令

tmosTaskID vavle_task_id = INVALID_TASK_ID;

#define ARRAY_SIZE(freq_arr) (sizeof(freq_arr) / sizeof((freq_arr)[0]))

/**
 * @description: From the frame start character to the sum of all bytes before the check code, modulo 256, i.e., the binary arithmetic sum of each byte without overflow value exceeding 255.
 * @param {uint8_t} *data
 * @param {uint16_t} len
 * @return {*}
 */
uint8_t CheckSum(const uint8_t *data, size_t len) // 计算校验和函数
{
    uint8_t sum = 0;

    for (size_t i = 0; i < len; i++)
    {
        sum += data[i];
    }

    return sum;
}

TsFrameData *BSP_VAVLE_GetFrameData(uint8_t *data, uint8_t len) // 获取阀门数据帧函数
{
    int ret        = 0;
    uint16_t index = 0;

    TsFrameData *get_buffer = NULL;

    if (len < 4)
    {
        logError("Data frame length insufficient");
        return NULL;
    }
    while (index < len && data[index] != FRAME_HEADER)
    {
        index++;
    }
    if (index >= len - 3)
    {
        logError("Data frame header error");
        return NULL;
    }
    uint16_t data_len = data[index + 2];
    if (index + 3 + data_len + 1 >= len)
    {
        logError("Data frame length error");
        return NULL;
    }

    uint8_t check_sum      = data[index + 3 + data_len];
    uint8_t calculated_sum = CheckSum(&data[index], data_len + 3);
    if (check_sum != calculated_sum)
    {
        logError("Data frame checksum error check_sum = %02X, calculated_sum = %02X", check_sum, calculated_sum);
        return NULL;
    }
    if (data[index + 3 + data_len + 1] != FRAME_TAIL)
    {
        logError("Data frame tail error");
        return NULL;
    }
    logDebug("Data frame verification passed");

    get_buffer = (TsFrameData *)tmos_msg_allocate(sizeof(TsFrameData) + sizeof(uint8_t) * data_len);
    if (get_buffer == NULL)
    {
        logError("tmos_msg_allocate fail");
        return NULL;
    }

    get_buffer->cmd = data[index + 1]; // 设置命令字段
    get_buffer->len = data_len;        // 设置长度字段
    //    get_buffer->data = data;

    if (data_len > 0)
    {
        tmos_memcpy(get_buffer->data, &data[index + 3], data_len);
        return get_buffer;
    }

    // //有效数据长度
    // size_t data_len = (data_len + 5);
    // //到这一步说明数据没问题，将接收到的数据通过中心任务发送出去
    // uint8_t *p_data;
    // p_data = tmos_msg_allocate(data_len);
    // if (p_data)
    // {
    //     tmos_memcpy(p_data, data, data_len);
    //     tmos_msg_send(BtRxTaskId, p_data);
    //     tmos_start_task(BtRxTaskId, SYS_EVENT_MSG, 0);
    // }
}

uint8_t GenerateRawFrame(TsRawFrameData *pRawData, uint8_t cmd, const uint8_t *p_src, uint8_t src_len) // 生成原始帧函数
{
    pRawData->len = src_len + 5;

    tmos_memset(pRawData->buf, 0, sizeof(pRawData->buf));

    pRawData->buf[0] = FRAME_HEADER;
    pRawData->buf[1] = cmd;
    pRawData->buf[2] = src_len;

    tmos_memcpy(&pRawData->buf[3], p_src, src_len);

    pRawData->buf[pRawData->len - 2] = CheckSum(&pRawData->buf[0], pRawData->len - 2);
    pRawData->buf[pRawData->len - 1] = FRAME_TAIL;

    return 0;
}

// void BSP_VALVE_Generate_UploadData(TsRawFrameData *pRawData) // 生成上传数据函数
// {
//     GenerateRawFrame(pRawData, kCmdData, (uint8_t *)&gValveData, sizeof(gValveData));
// }

void BSP_VALVE_Generate_Data(TsRawFrameData *pRawData, TeFrameCmd cmd) // 生成阀门数据函数
{
    TsValveData ValveData;
    // uint8_t MacAddr[6];
    // GetMACAddress(MacAddr);

    // ValveData.valve_id  = 1;
    // tmos_memset(ValveData.valve_mac, 0, sizeof(ValveData.valve_mac));
    // tmos_memcpy(ValveData.valve_mac, MacAddr, sizeof(ValveData.valve_mac));

    // ValveData.connct_status = gValveData.connct_status;
    ValveData.switch_status = gValveData.switch_status;
    ValveData.temp          = ValveRawData.atom_temp;

    ValveData.in_pressure  = ValveRawData.in_press_raw;
    ValveData.out_pressure = ValveRawData.out_press_raw;
    ValveData.atm_pressure = ValveRawData.atom_press;

    ValveData.type = kZbf;
    ValveData.bat  = BSP_ReadVbat();
    ValveData.humi = 50;
    ValveData.rssi = gValveData.rssi;

    ValveData.Lock = gValveData.Lock;
    ValveData.over_pressure = ValveInfo.over_press;
    ValveData.under_pressure = ValveInfo.low_press;
    ValveData.over_temp = ValveInfo.over_temp;
    ValveData.delay_close_time = ValveInfo.delay_close_count * 5;

    // 打印ValveData的所有字段
    logDebug("ValveData info:\r\n"
             "switch_status: %d\r\n"
             "temp: %d\r\n"
             "in_pressure: %d\r\n"
             "out_pressure: %d\r\n"
             "atm_pressure: %d\r\n"
             "type: %d\r\n"
             "bat: %d\r\n"
             "humi: %d\r\n"
             "rssi: %d\r\n"
             "Lock: %d\r\n"
             "over_pressure: %d\r\n"
             "under_pressure: %d\r\n"
             "over_temp: %d\r\n"
             "delay_close_time: %d",
             ValveData.switch_status,
             ValveData.temp,
             ValveData.in_pressure,
             ValveData.out_pressure,
             ValveData.atm_pressure,
             ValveData.type,
             ValveData.bat,
             ValveData.humi,
             ValveData.rssi,
             ValveData.Lock,
             ValveData.over_pressure,
             ValveData.under_pressure,
             ValveData.over_temp,
             ValveData.delay_close_time);

    GenerateRawFrame(pRawData, cmd, (uint8_t *)&ValveData, sizeof(ValveData));
}


// void BSP_VALVE_Generate_ValveResponse(TsRawFrameData *pRawData, TeFrameCmd cmd, uint8_t status) // 生成阀门响应函数
// {
//     uint8_t data = 0;
//     data         = status;
//     GenerateRawFrame(pRawData, cmd, &data, 1);
// }

static void VAVLE_Task_ProcessTmosMsg(uint8_t *p_rev_msg) // 处理TMOS消息函数
{
    if (p_rev_msg)
    {
#if 1
        TsFrameData *HostFrameData = BSP_VAVLE_GetFrameData(&p_rev_msg[1], p_rev_msg[0]);
        if (HostFrameData != NULL)
        {
            switch (HostFrameData->cmd)
            {
                case kCmdCfg:          // 配置命令
                    logDebug("kCmdCfg");
                    break;
                case kCmdCloseVavle:   // 关阀命令
                    logDebug("kCmdCloseVavle");
                    uint8_t CloseStatus = 0;
                    CloseStatus = BSP_VALVE_Close(kCmdCloseVavle); // 使用普通关阀命令
                    if(CloseStatus == 1)
                    {
                        BSP_VALVE_Generate_Data(&RelyData, kCmdCloseVavle);
                        tmos_set_event(Peripheral_TaskID, SBP_REPLY_CMD_EVT);  
                    }
                    break;

                case kCmdOpenVavle:    // 开阀命令
                    logDebug("kCmdOpenVavle");
                    uint8_t OpenStatus = 0;
                    OpenStatus = BSP_VALVE_Open(kCmdOpenVavle);  // 使用普通开阀命令
                    if(OpenStatus == 1)
                    {
                        BSP_VALVE_Generate_Data(&RelyData, kCmdOpenVavle);
                        tmos_set_event(Peripheral_TaskID, SBP_REPLY_CMD_EVT);  
                    }
                    else if(OpenStatus == 2)
                    {
                        BSP_VALVE_Generate_Data(&RelyData, valve_safety.lock_reason);
                        tmos_set_event(Peripheral_TaskID, SBP_REPLY_CMD_EVT);  
                    }
                    break;
                case KValveCmdTimeSet:   // 设置定时关阀命令
                {
                    uint8_t result = 0;
                    if (HostFrameData->len >= 2) {
                        uint32_t minutes = 0;
                        tmos_memcpy(&minutes, HostFrameData->data, 2);  // 安全的内存拷贝
                        result = BSP_VALVE_SetTimerClose(minutes);
                        logDebug("kValveCmdTimer: %d minutes, result: %d", minutes, result);
                    }
                    // 生成响应: 设置的分钟数(2字节) + 状态(1字节)
                    uint8_t response[3] = {result};
                    tmos_memcpy(&response[1], &gTimerCloseState.timer_minutes, 2);  // 安全的内存拷贝
                    GenerateRawFrame(&RelyData, kValveCmdTimeResp, response, 3);
                    tmos_set_event(Peripheral_TaskID, SBP_REPLY_CMD_EVT);
                    break;
                }
                // 定时器取消和查询功能暂时屏蔽
                /*
                case kCmdCancelTimer:  // 取消定时关阀命令
                {
                    uint8_t result = BSP_VALVE_CancelTimerClose();
                    logDebug("kCmdCancelTimer: result: %d", result);
                    BSP_VALVE_Generate_ValveResponse(&RelyData, kCmdCancelTimer, result);
                    tmos_set_event(Peripheral_TaskID, SBP_REPLY_CMD_EVT);
                    break;
                }
                case kCmdQueryTimer:   // 查询定时器状态命令
                {
                    uint32_t remaining = BSP_VALVE_GetRemainingMinutes();
                    uint8_t response[5];
                    response[0] = gTimerCloseState.is_active;
                    tmos_memcpy(&response[1], &remaining, 4);  // 安全的内存拷贝
                    logDebug("kCmdQueryTimer: active: %d, remaining: %d", gTimerCloseState.is_active, remaining);
                    GenerateRawFrame(&RelyData, kCmdQueryTimer, response, 5);
                    tmos_set_event(Peripheral_TaskID, SBP_REPLY_CMD_EVT);
                    break;
                }
                */
                default:
                    logError("Invalid command");
                    break;
            }
        }
        else
        {
            logError("Data frame parsing failed");
        }
        tmos_msg_deallocate((uint8_t *)HostFrameData);
        HostFrameData = NULL;
#endif
    }
    else
    {
        logError("pMsg is NULL");
    }
}

static uint16_t VAVLE_Task_ProcessEvent(uint8_t task_id, uint16_t events) // 阀门任务事件处理函数
{
    if (events & SYS_EVENT_MSG)        // 系统消息事件
    {
        uint8_t *p_rev_msg;
        if ((p_rev_msg = tmos_msg_receive(vavle_task_id)) != NULL)
        {
            VAVLE_Task_ProcessTmosMsg(p_rev_msg);
            tmos_msg_deallocate(p_rev_msg);
        }
        return (events ^ SYS_EVENT_MSG);
    }
    if (events & VAVLE_RX_DATA_EVT)    // 阀门接收数据事件
    {
        logDebug("VAVLE_RX_DATA_EVT");

        return (events ^ VAVLE_RX_DATA_EVT);
    }
    if (events & VAVLE_TX_DATA_EVT)    // 阀门发送数据事件
    {
        logDebug("VAVLE_TX_DATA_EVT");

        return (events ^ VAVLE_TX_DATA_EVT);
    }
    if (events & VAVLE_CLOSE_START_EVT) // 阀门关闭开始事件
    {
        logDebug("VAVLE_CLOSE_START_EVT");

        BSP_BlockSleep();
        BSP_MOTOR_Init();
        LED_VALVE_CLOSE;
        // DelayUs(200);

        VALVE_STOP();

        logDebug("MOTOR_INIT");

        tmos_start_task(vavle_task_id, VAVLE_CLOSE_ACTION_EVT, MS1_TO_SYSTEM_TIME(200));

        return (events ^ VAVLE_CLOSE_START_EVT);
    }
    if (events & VAVLE_CLOSE_ACTION_EVT) // 阀门关闭动作事件
    {
        BSP_BlockSleep();
        logDebug("VAVLE_CLOSE_ACTION_EVT");

        VALVE_CLOSE();

        logDebug("VALVE_CLOSE");

        tmos_start_task(vavle_task_id, VAVLE_CLOSE_END_EVT, MS1_TO_SYSTEM_TIME(CHARGE_TIME_MS));

        return (events ^ VAVLE_CLOSE_ACTION_EVT);
    }
    if (events & VAVLE_CLOSE_END_EVT)  // 阀门关闭结束事件
    {
        VALVE_STOP();
        LED_ALL_CLOSE;
        logWarning("gValveCloseReason  %d",gValveCloseReason);
        // gValveCloseReason = kCmdData;
        tmos_memset(&RelyData, 0, sizeof(RelyData));
        // BSP_VALVE_Generate_ValveResponse(&RelyData, gValveCloseReason, 1);
        BSP_VALVE_Generate_Data(&RelyData, gValveCloseReason);
        // 重置为默认值
        gValveCloseReason = kCmdCloseVavle;

        tmos_set_event(Peripheral_TaskID, SBP_REPLY_CMD_EVT);

        if (IotFlag_t.Date_Sending_flag == 0) 
        {
            BSP_RequestSleep();
        }
        logDebug("VAVLE_CLOSE_END_EVT");
        Iot_Send_Data(gValveCloseReason);
        return (events ^ VAVLE_CLOSE_END_EVT);
    }

    if (events & VAVLE_OPEN_START_EVT)    // 阀门打开开始事件
    {
        logDebug("VAVLE_OPEN_START_EVT");

        BSP_BlockSleep();
        BSP_MOTOR_Init();
        LED_VALVE_OPEN;
        // DelayUs(200);

        VALVE_STOP();

        logDebug("MOTOR_INIT");

        tmos_start_task(vavle_task_id, VAVLE_OPEN_ACTION_EVT, MS1_TO_SYSTEM_TIME(200));

        return (events ^ VAVLE_OPEN_START_EVT);
    }

    if (events & VAVLE_OPEN_ACTION_EVT)    // 阀门打开动作事件
    {
        BSP_BlockSleep();
        logDebug("VAVLE_OPEN_ACTION_EVT");

        VALVE_OPEN();
        keydown_flag = 1;
        logDebug("VALVE_OPEN");

        tmos_start_task(vavle_task_id, VAVLE_OPEN_END_EVT, MS1_TO_SYSTEM_TIME(CHARGE_TIME_MS));

        return (events ^ VAVLE_OPEN_ACTION_EVT);
    }

    if (events & VAVLE_OPEN_END_EVT)    // 阀门打开结束事件
    {
        VALVE_STOP();
        LED_ALL_CLOSE;
        logWarning("gValveOpenReason  %d",gValveOpenReason);
        // gValveOpenReason = kCmdData;
        // 生成响应
        tmos_memset(&RelyData, 0, sizeof(RelyData));
        // BSP_VALVE_Generate_ValveResponse(&RelyData, gValveOpenReason, 1);
        BSP_VALVE_Generate_Data(&RelyData, gValveOpenReason);
        
        // 重置为默认值
        gValveOpenReason = kCmdOpenVavle;

        tmos_set_event(Peripheral_TaskID, SBP_REPLY_CMD_EVT);
        if (IotFlag_t.Date_Sending_flag == 0) 
        {
            BSP_RequestSleep();
        }
        
        Iot_Send_Data(gValveOpenReason);
        // 启动微泄漏检测
        startMicroLeakDetection();
        
        logDebug("VAVLE_OPEN_END_EVT");
        return (events ^ VAVLE_OPEN_END_EVT);
    }

    if (events & VAVLE_LOOP_DECT_EVT)    // 循环检测事件
    {
        logDebug("VAVLE_LOOP_DECT_EVT");

        gValveData.bat = BSP_ReadVbat()/100;
        logDebug("BSP_ReadVbat %d",gValveData.bat);

        // 电压过低就关阀
        if (gValveData.bat <= LOW_VABAT_CLOSE_VALUE)
        {
            logDebug("gValveData.switch_status %d",gValveData.switch_status);
            if(gValveData.switch_status != kClosed)
            {
                BSP_VALVE_Close(kValveCmdLowBatClose); // 低电量关阀命令
            }
        }
        else if (gValveData.bat <= LOW_VABAT_ALARM_VALUE)
        {
            tmos_set_event(vavle_task_id, VAVLE_LOW_VBAT_ALARM_EVT);
        }

        tmos_start_task(vavle_task_id, VAVLE_LOOP_DECT_EVT, MS1_TO_SYSTEM_TIME(VALVE_DECT_PERIOD_MS));

        return (events ^ VAVLE_LOOP_DECT_EVT);
    }

    if (events & VAVLE_LOW_VBAT_ALARM_EVT)  // 低电压报警事件
    {
        gValveData.bat = BSP_ReadVbat()/100;
        if (gValveData.bat > 25)
        {
            return (events ^ VAVLE_LOW_VBAT_ALARM_EVT);
        }
        logDebug("VAVLE_LOW_VBAT_ALARM_EVT");

        BSP_BlockSleep();
        LED_VBAT_OPEN;

        tmos_start_task(vavle_task_id, VAVLE_LOW_VBAT_LED_OFF_EVT, MS1_TO_SYSTEM_TIME(500));

        tmos_start_task(vavle_task_id, VAVLE_LOW_VBAT_ALARM_EVT, MS1_TO_SYSTEM_TIME(5000));  // VALVE_LOW_VBAT_ALARM_PERIOD_MS

        // tmos_set_event(vavle_task_id, VAVLE_CLOSE_START_EVT);  // 设置阀门关闭开始事件

        // tmos_start_task(vavle_task_id, VAVLE_LOW_VBAT_ALARM_EVT, MS1_TO_SYSTEM_TIME(VALVE_LOW_VBAT_ALARM_PERIOD_MS));  // 启动低电压报警事件，延时一段时间

        return (events ^ VAVLE_LOW_VBAT_ALARM_EVT);
    }
    if (events & VAVLE_LOW_VBAT_LED_OFF_EVT) // 低电压LED关闭事件
    {
        LED_VBAT_CLOSE;
        BSP_RequestSleep();
        return (events ^ VAVLE_LOW_VBAT_LED_OFF_EVT);
    }

    if (events & VAVLE_TIMER_CLOSE_EVT) // 定时关阀事件
    {
        logInfo("Timer close triggered - auto closing valve");
        
        // 清除定时器状态
        gTimerCloseState.is_active = 0;
        gTimerCloseState.timer_minutes = 0;
        
        // 使用统一接口关阀
        BSP_VALVE_Close(kValveCmdTimer);
        
        // // 发送定时关阀完成通知
        // uint8_t notification = 1;  // 定时关阀完成
        // GenerateRawFrame(&RelyData, kValveCmdTimeResp, &notification, 1);
        // tmos_set_event(Peripheral_TaskID, SBP_REPLY_CMD_EVT);
        
        return (events ^ VAVLE_TIMER_CLOSE_EVT);
    }
    if (events & VAVLE_ALARM_LED_REFRESH_EVT) // ±¨¾¯LEDË¢ÐÂÊÂ¼þ
    {
        if (gValveData.Lock == 1)
        {
            LED_ALARM_OPEN;
            DelayMs(10);
            tmos_start_task(vavle_task_id, VAVLE_ALARM_LED_REFRESH_EVT, MS1_TO_SYSTEM_TIME(VALVE_ALARM_LED_REFRESH_PERIOD_MS));
        }
        return (events ^ VAVLE_ALARM_LED_REFRESH_EVT);
    }

    return 0;
}

void BSP_VAVLE_Init(void)  // 阀门初始化函数
{
    vavle_task_id = TMOS_ProcessEventRegister(VAVLE_Task_ProcessEvent);
    tmos_memset(&gValveData, 0, sizeof(gValveData));
    
    // 初始化定时器状态
    tmos_memset(&gTimerCloseState, 0, sizeof(gTimerCloseState));

    gValveData.temp = -100;
    gValveData.in_pressure = 0;
    gValveData.out_pressure = 0;
    gValveData.atm_pressure = 0;

    gValveData.type = kTyq;            // 设置阀门类型
    gValveData.bat = BSP_ReadVbat()/100;   // 读取电池电压

    BSP_MOTOR_Init();                  // 初始化电机

    tmos_start_task(vavle_task_id, VAVLE_LOOP_DECT_EVT, MS1_TO_SYSTEM_TIME(1000));  //VALVE_DECT_PERIOD_MS

    logInfo("BSP_Valve_Init");

    gValveData.switch_status = kClosed;  // 初始化阀门状态为关闭
}

uint8_t BSP_VALVE_SetTimerClose(uint32_t minutes)
{
    // 参数验证
    if (minutes == 0 || minutes > 1440) {  // 1分钟到24小时
        logError("Invalid timer minutes: %d", minutes);
        return 1;  // 设置失败
    }
    
    // 检查当前阀门状态，如果已经关闭则不需要定时关阀
    if (gValveData.switch_status == kClosed) {
        logDebug("Valve already closed, timer not needed");
        return 1;  // 阀门已关闭
    }
    
    // 停止现有定时器（如果有）
    if (gTimerCloseState.is_active) {
        tmos_stop_task(vavle_task_id, VAVLE_TIMER_CLOSE_EVT);
        logDebug("Stopped existing timer");
    }
    
    // 设置新的定时器
    gTimerCloseState.timer_minutes = minutes;
    gTimerCloseState.start_time = BSP_Get_Tick();
    gTimerCloseState.is_active = 1;
    
    // 启动TMOS定时器
    uint32_t delay_ms = minutes * 60 * 1000;
    tmos_start_task(vavle_task_id, VAVLE_TIMER_CLOSE_EVT, MS1_TO_SYSTEM_TIME(delay_ms));
    
    logInfo("Timer close set: %d minutes", minutes);
    return 0;  // 设置成功
}

static uint8_t BSP_VALVE_CancelTimerClose(void)
{
    if (!gTimerCloseState.is_active) {
        logDebug("No active timer to cancel");
        return 1;  // 没有激活的定时器
    }
    
    // 停止定时器
    tmos_stop_task(vavle_task_id, VAVLE_TIMER_CLOSE_EVT);
    
    // 清除状态
    gTimerCloseState.is_active = 0;
    gTimerCloseState.timer_minutes = 0;
    
    logInfo("Timer close cancelled");
    return 0;  // 取消成功
}

static uint32_t BSP_VALVE_GetRemainingMinutes(void)
{
    if (!gTimerCloseState.is_active) {
        return 0;  // 没有激活的定时器
    }
    
    uint32_t elapsed_ms = BSP_Get_Tick() - gTimerCloseState.start_time;
    uint32_t total_ms = gTimerCloseState.timer_minutes * 60 * 1000;
    
    if (elapsed_ms >= total_ms) {
        return 0;  // 时间已到
    }
    
    uint32_t remaining_ms = total_ms - elapsed_ms;
    return (remaining_ms / 60000) + 1;  // 向上取整到分钟
}

/**
 * @brief 统一的关阀接口函数
 * @param close_reason 关阀原因，使用TeFrameCmd中定义的枚举值
 * @return 操作结果
 */
uint8_t BSP_VALVE_Close(TeFrameCmd close_reason)
{
    // 如果阀门已经关闭，则不重复操作
    if(gValveData.switch_status == kClosed) {
        return 1;
    }
    
    // 设置关阀原因
    gValveCloseReason = close_reason;
    LED_VALVE_CLOSE;
    // 触发关阀事件
    tmos_set_event(vavle_task_id, VAVLE_CLOSE_START_EVT);
    
    return 0;
}

/**
 * @brief 统一的开阀接口函数
 * @param open_reason 开阀原因，使用TeFrameCmd中定义的枚举值
 * @return 操作结果
 */
uint8_t BSP_VALVE_Lock(TeFrameCmd lock_reason)
{
    if(gValveData.Lock == 1) {
        return 1;
    }
    valve_safety.lock_reason = lock_reason;
    LED_ALARM_OPEN;
    gValveData.Lock = 1;
    tmos_start_task(vavle_task_id, VAVLE_ALARM_LED_REFRESH_EVT, MS1_TO_SYSTEM_TIME(VALVE_ALARM_LED_REFRESH_PERIOD_MS));
    logWarning("switch_status: %d", gValveData.switch_status);
    return 0;
}
uint8_t BSP_VALVE_Unlock(void)
{
    if(gValveData.Lock != 1) {
        return 1;
    }
    LED_ALARM_CLOSE;
    tmos_stop_task(vavle_task_id, VAVLE_ALARM_LED_REFRESH_EVT);
    gValveData.Lock = 0;
    return 0;
}
uint8_t BSP_VALVE_CheckHazardCleared(void)
{
    switch(valve_safety.lock_reason)
    {
        case kValveCmdOverPressure:  
            if(ValveRawData.in_press < ValveInfo.over_press) {
                return 1; 
            }
            break;
        case kValveCmdUnderPressure:  
            if(ValveRawData.in_press > ValveInfo.low_press) {
                return 1; 
            }
            break;
        case kValveCmdMicroLeak:       
            if (valve_safety.micro_leak_count == 0) {
                logInfo("需手动解锁");
                return 1;
            }  
            break;
        case kValveCmdOverCurrent:     
            return 0;
        default:
            return 1;
    }
    return 0; 
}
uint8_t BSP_VALVE_Open(TeFrameCmd open_reason)
{
    // 如果阀门已经打开，则不重复操作
    if(gValveData.switch_status == kOpened) {
        return 1;
    }
    
    logWarning("switch_status: %d", gValveData.switch_status);
    if(gValveData.Lock == 1) {
        logWarning("lock_reason: %d", valve_safety.lock_reason);
        return 2; 
    }
    gValveOpenReason = open_reason;
    LED_VALVE_OPEN;
    // 触发开阀事件
    tmos_set_event(vavle_task_id, VAVLE_OPEN_START_EVT);
    
    return 0;
}


